import { TextlintRuleContext, TextlintRuleContextArgs, TextlintRuleError, TextlintRuleReportedObject, TextlintRuleSeverityLevel } from "@textlint/types";
import { ASTNodeTypes, TxtNode } from "@textlint/ast-node-types";
import { TextlintRuleContextFixCommandGeneratorImpl } from "./TextlintRuleContextFixCommandGeneratorImpl";
import { TextlintRuleErrorImpl } from "./TextlintRuleErrorImpl";
export declare class TextlintRuleContextImpl implements TextlintRuleContext {
    private _ruleId;
    private _sourceCode;
    private _report;
    private _configBaseDir?;
    private _severityLevel;
    constructor(args: TextlintRuleContextArgs);
    /**
     * Rule id
     * @returns {string}
     */
    readonly id: string;
    /**
     * severity level
     */
    readonly severity: TextlintRuleSeverityLevel;
    /**
     * Node's type values
     * @type {ASTNodeTypes}
     */
    readonly Syntax: typeof ASTNodeTypes;
    /**
     * CustomError object
     * @type {RuleError}
     */
    readonly RuleError: typeof TextlintRuleErrorImpl;
    /**
     * Rule fixer command object
     * @type {RuleFixer}
     */
    readonly fixer: TextlintRuleContextFixCommandGeneratorImpl;
    /**
     * report function that is called in a rule
     */
    report: (node: TxtNode, ruleError: TextlintRuleReportedObject | TextlintRuleError, _shouldNotUsed?: any) => void;
    /**
     * get file path current processing.
     */
    getFilePath: () => string | undefined;
    /**
     * Gets the source code for the given node.
     * @param {TxtNode=} node The AST node to get the text for.
     * @param {int=} beforeCount The number of characters before the node to retrieve.
     * @param {int=} afterCount The number of characters after the node to retrieve.
     * @returns {string} The text representing the AST node.
     */
    getSource: (node?: TxtNode | undefined, beforeCount?: number | undefined, afterCount?: number | undefined) => string;
    /**
     * get config base directory path
     * config base directory path often is the place of .textlintrc
     *
     * e.g.) /path/to/dir/.textlintrc
     * `getConfigBaseDir()` return `"/path/to/dir/"`.
     *
     * When using textlint as module, it is specified by `configBaseDir`
     * If not found the value, return undefined.
     *
     * You can use it for resolving relative path from config dir.
     * @returns {string|undefined}
     */
    getConfigBaseDir: () => string | undefined;
}
