import { TextlintKernelFilterRule } from "../textlint-kernel-interface";
import { Descriptor } from "./Descriptor";
import { TextlintFilterRuleOptions, TextlintFilterRuleReporter } from "@textlint/types";
/**
 * Textlint Rule Descriptor.
 * It handle RuleCreator and RuleOption.
 */
export declare class TextlintFilterRuleDescriptor implements Descriptor<TextlintKernelFilterRule> {
    private kernelFilterRule;
    constructor(kernelFilterRule: TextlintKernelFilterRule);
    readonly id: string;
    readonly rule: TextlintFilterRuleReporter;
    /**
     * Return true if this rule is enabled.
     */
    readonly enabled: boolean;
    /**
     * Return filter function
     * You should check hasLiner before call this.
     */
    readonly filter: TextlintFilterRuleReporter;
    /**
     * Return normalized rule option object.
     * If the rule have not option, return `true` by default.
     */
    readonly normalizedOptions: TextlintFilterRuleOptions;
    readonly rawOptions: undefined | boolean | TextlintFilterRuleOptions;
    /**
     * Return true if descriptor is same
     */
    equals(descriptor: this): boolean;
    toKernel(): TextlintKernelFilterRule;
}
